@@ -3,12 +3,10 @@ import sys
 import unittest
 from unittest.mock import MagicMock, patch
 
-import pytest
-
 sys.path.insert(
     0, os.path.abspath(os.path.join(os.path.dirname(__file__), "../src"))
 )
-from edit_python_pe.main import MemberApp
+from edit_python_pe.main import MemberApp, fork_repo, get_repo, main
 
 
 class TestMemberApp(unittest.TestCase):
@@ -16,7 +14,14 @@ class TestMemberApp(unittest.TestCase):
         # Patch Github and Repository for testing
         self.token = "fake-token"
         self.repo = MagicMock()
-        self.app = MemberApp(token=self.token, original_repo=self.repo)
+        self.original_repo = MagicMock()
+        self.forked_repo = MagicMock()
+        self.app = MemberApp(
+            repo_path="test_repo",
+            original_repo=self.original_repo,
+            forked_repo=self.forked_repo,
+            token=self.token,
+        )
         self.app.social_container = MagicMock()
         self.app.alias_container = MagicMock()
         self.app.list_container = MagicMock()
@@ -27,7 +32,7 @@ class TestMemberApp(unittest.TestCase):
         self.app.social_index = 0
         self.app.alias_index = 0
 
-        # Mock UI elements and REPO_PATH
+        # Mock UI elements
         # Use simple stub classes for input widgets and text areas
         class StubInput:
             def __init__(self):
@@ -41,12 +46,10 @@ class TestMemberApp(unittest.TestCase):
         self.app.email_input = StubInput()
         self.app.city_input = StubInput()
         self.app.homepage_input = StubInput()
-        self.app.about_me_area = StubTextArea()
         self.app.who_area = StubTextArea()
         self.app.python_area = StubTextArea()
         self.app.contributions_area = StubTextArea()
         self.app.availability_area = StubTextArea()
-        self.app.REPO_PATH = "test_repo"
 
         # Patch remove method for entries to avoid Textual lifecycle errors
         # Use stub classes for entries with .remove() method
@@ -96,7 +99,6 @@ class TestMemberApp(unittest.TestCase):
         self.app.email_input.value = "filled@email.com"
         self.app.city_input.value = "Filled City"
         self.app.homepage_input.value = "https://filled-homepage.com"
-        self.app.about_me_area.text = "Filled About me"
         self.app.who_area.text = "Filled Who am I"
         self.app.python_area.text = "Filled Python stuff"
         self.app.contributions_area.text = "Filled Contributions"
@@ -104,22 +106,30 @@ class TestMemberApp(unittest.TestCase):
         # Add social and alias entries
         self.app.social_entries = [self.StubSocialEntry()]
         self.app.alias_entries = [self.StubAliasEntry()]
+
         # Simulate pressing the 'Añadir' button on the list screen
         class DummyButton:
             id = "add_list"
+
         class DummyEvent:
             button = DummyButton()
+
         self.app.on_button_pressed(DummyEvent())
         # After pressing, form should be cleared and current_file should be None
         self.assertEqual(self.app.name_input.value, "")
         self.assertEqual(self.app.email_input.value, "")
         self.assertEqual(self.app.city_input.value, "")
         self.assertEqual(self.app.homepage_input.value, "")
-        self.assertEqual(self.app.about_me_area.text, "Sobre mí")
-        self.assertEqual(self.app.who_area.text, "¿Quién eres y a qué te dedicas?")
-        self.assertEqual(self.app.python_area.text, "¿Cómo programas en Python?")
-        self.assertEqual(self.app.contributions_area.text, "¿Tienes algún aporte a la comunidad de Python?")
-        self.assertEqual(self.app.availability_area.text, "¿Estás disponible para hacer mentoring, consultorías, charlas?")
+        self.assertEqual(self.app.who_area.text, "")
+        self.assertEqual(self.app.python_area.text, "")
+        self.assertEqual(
+            self.app.contributions_area.text,
+            "",
+        )
+        self.assertEqual(
+            self.app.availability_area.text,
+            "",
+        )
         self.assertEqual(len(self.app.social_entries), 0)
         self.assertEqual(len(self.app.alias_entries), 0)
         self.assertIsNone(self.app.current_file)
@@ -145,10 +155,7 @@ class TestMemberApp(unittest.TestCase):
 
     def test_save_member_edit_no_pr(self):
         """Test editing an existing member without a matching PR in save_member."""
-        from unittest.mock import MagicMock, patch
-
         app = self.app
-        app.REPO_PATH = "/tmp/testrepo"
         app.current_file = "existing_member.md"
         app.token = "fake-token"
         app.forked_repo = MagicMock()
@@ -160,7 +167,7 @@ class TestMemberApp(unittest.TestCase):
         with (
             patch("os.makedirs") as makedirs,
             patch("builtins.open", MagicMock()),
-            patch("pygit2.Repository") as RepoMock,
+            patch("pygit2.repository.Repository") as RepoMock,
         ):
             repo_instance = RepoMock.return_value
             repo_instance.index.add = MagicMock()
@@ -176,7 +183,6 @@ class TestMemberApp(unittest.TestCase):
             app.email_input.value = "test@email.com"
             app.city_input.value = "Test City"
             app.homepage_input.value = "https://homepage.com"
-            app.about_me_area.text = "About me"
             app.who_area.text = "Who am I"
             app.python_area.text = "Python stuff"
             app.contributions_area.text = "Contributions"
@@ -194,7 +200,7 @@ class TestMemberApp(unittest.TestCase):
             app.social_entries.append(social_entry)
             app.save_member()
             makedirs.assert_called()
-            repo_instance.index.add.assert_called()
+            repo_instance.index.add_all.assert_called()
             repo_instance.create_commit.assert_called()
             repo_instance.remotes["origin"].push.assert_called()
             app.original_repo.create_pull.assert_called()
@@ -204,7 +210,6 @@ class TestMemberApp(unittest.TestCase):
         from unittest.mock import MagicMock, patch
 
         app = self.app
-        app.REPO_PATH = "/tmp/testrepo"
         app.current_file = "existing_member.md"
         app.token = "fake-token"
         app.forked_repo = MagicMock()
@@ -219,7 +224,7 @@ class TestMemberApp(unittest.TestCase):
         with (
             patch("os.makedirs") as makedirs,
             patch("builtins.open", MagicMock()),
-            patch("pygit2.Repository") as RepoMock,
+            patch("pygit2.repository.Repository") as RepoMock,
         ):
             repo_instance = RepoMock.return_value
             repo_instance.index.add = MagicMock()
@@ -235,7 +240,6 @@ class TestMemberApp(unittest.TestCase):
             app.email_input.value = "test@email.com"
             app.city_input.value = "Test City"
             app.homepage_input.value = "https://homepage.com"
-            app.about_me_area.text = "About me"
             app.who_area.text = "Who am I"
             app.python_area.text = "Python stuff"
             app.contributions_area.text = "Contributions"
@@ -253,7 +257,7 @@ class TestMemberApp(unittest.TestCase):
             app.social_entries.append(social_entry)
             app.save_member()
             makedirs.assert_called()
-            repo_instance.index.add.assert_called()
+            repo_instance.index.add_all.assert_called()
             repo_instance.create_commit.assert_called()
             repo_instance.remotes["origin"].push.assert_called()
             # Instead of asserting create_pull is not called, check that get_pulls was called and the PR was handled.
@@ -263,11 +267,7 @@ class TestMemberApp(unittest.TestCase):
 
     def test_save_member_new(self):
         """Test creating a new member scenario in save_member."""
-        import builtins
-        from unittest.mock import MagicMock, patch
-
         app = self.app
-        app.REPO_PATH = "/tmp/testrepo"
         app.current_file = None
         app.token = "fake-token"
         app.forked_repo = MagicMock()
@@ -277,7 +277,7 @@ class TestMemberApp(unittest.TestCase):
         with (
             patch("os.makedirs") as makedirs,
             patch("builtins.open", MagicMock()),
-            patch("pygit2.Repository") as RepoMock,
+            patch("pygit2.repository.Repository") as RepoMock,
         ):
             repo_instance = RepoMock.return_value
             repo_instance.index.add = MagicMock()
@@ -291,7 +291,6 @@ class TestMemberApp(unittest.TestCase):
             app.email_input.value = "test@email.com"
             app.city_input.value = "Test City"
             app.homepage_input.value = "https://homepage.com"
-            app.about_me_area.text = "About me"
             app.who_area.text = "Who am I"
             app.python_area.text = "Python stuff"
             app.contributions_area.text = "Contributions"
@@ -309,17 +308,14 @@ class TestMemberApp(unittest.TestCase):
             app.social_entries.append(social_entry)
             app.save_member()
             makedirs.assert_called()
-            repo_instance.index.add.assert_called()
+            repo_instance.index.add_all.assert_called()
             repo_instance.create_commit.assert_called()
             repo_instance.remotes["origin"].push.assert_called()
             app.original_repo.create_pull.assert_called()
 
     def test_save_member_error_handling(self):
         """Test error handling in save_member when required fields are missing."""
-        from unittest.mock import MagicMock, patch
-
         app = self.app
-        app.REPO_PATH = "/tmp/testrepo"
         app.current_file = None
         app.token = "fake-token"
         app.forked_repo = MagicMock()
@@ -331,14 +327,13 @@ class TestMemberApp(unittest.TestCase):
             patch.object(app, "exit") as exit_mock,
             patch("os.makedirs"),
             patch("builtins.open", MagicMock()),
-            patch("pygit2.Repository"),
+            patch("pygit2.repository.Repository"),
         ):
             # Leave name and email blank to trigger error
             app.name_input.value = ""
             app.email_input.value = ""
             app.city_input.value = ""
             app.homepage_input.value = ""
-            app.about_me_area.text = ""
             app.who_area.text = ""
             app.python_area.text = ""
             app.contributions_area.text = ""
@@ -454,4 +449,300 @@ class: "member-gravatar"
         self.assertEqual(self.app.city_input.value, "Lima")
         self.assertEqual(self.app.homepage_input.value, "https://joe-doe.org")
         self.assertGreaterEqual(len(self.app.social_entries), 1)
-        self.assertGreaterEqual(len(self.app.alias_entries), 1)
+
+
+class TestUtilityFunctions(unittest.TestCase):
+    def test_create_member_file(self):
+        from unittest.mock import patch
+
+        from edit_python_pe.main import create_member_file
+
+        file_content = "Sample member content"
+        current_file = None
+        repo_path = "/fake/repo"
+        aliases = ["alias1"]
+        name = "Test Name"
+        email = "test@email.com"
+        expected_filename_prefix = "alias1-"
+        with patch("edit_python_pe.main.write_file") as mock_write_file:
+            name_file, file_path = create_member_file(
+                file_content, current_file, repo_path, aliases, name, email
+            )
+            mock_write_file.assert_called_once_with(file_content, file_path)
+            self.assertTrue(name_file.startswith(expected_filename_prefix))
+            self.assertTrue(name_file.endswith(".md"))
+            self.assertIn("blog/members/", file_path)
+            self.assertTrue(file_path.endswith(name_file))
+
+        # Test with current_file provided
+        current_file = "existing.md"
+        with patch("edit_python_pe.main.write_file") as mock_write_file:
+            name_file, file_path = create_member_file(
+                file_content, current_file, repo_path, aliases, name, email
+            )
+            self.assertEqual(name_file, current_file)
+            self.assertTrue(file_path.endswith(current_file))
+            mock_write_file.assert_called_once_with(file_content, file_path)
+
+        name = "Test Name"
+        email = "test@email.com"
+
+    def test_write_authors_file(self):
+        from unittest.mock import patch
+
+        from edit_python_pe.main import write_authors_file
+
+        repo_path = "/fake/repo"
+        aliases = ["alias1"]
+        name = "Test Name"
+        email = "test@email.com"
+        file_path = f"{repo_path}/AUTHORS"
+        # Case: author not present, should append
+        with (
+            patch(
+                "edit_python_pe.main.read_file", return_value=""
+            ) as mock_read_file,
+            patch("edit_python_pe.main.append_file") as mock_append_file,
+        ):
+            write_authors_file(repo_path, aliases, name, email)
+            mock_read_file.assert_called_once_with(file_path)
+            mock_append_file.assert_called_once()
+            args, _ = mock_append_file.call_args
+            self.assertIn(name, args[0])
+            self.assertIn(email, args[0])
+
+        # Case: author already present, should not append
+        existing_line = f"\n{name}(alias1) <{email}>"
+        with (
+            patch(
+                "edit_python_pe.main.read_file", return_value=existing_line
+            ) as mock_read_file,
+            patch("edit_python_pe.main.append_file") as mock_append_file,
+        ):
+            write_authors_file(repo_path, aliases, name, email)
+            mock_read_file.assert_called_once_with(file_path)
+            mock_append_file.assert_not_called()
+
+    def test_get_alias(self):
+        from edit_python_pe.main import get_alias
+
+        # Case: aliases present
+        aliases = ["CoolAlias"]
+        name = "John Doe"
+        self.assertEqual(get_alias(aliases, name), "CoolAlias")
+        # Case: aliases absent
+        aliases = []
+        self.assertEqual(get_alias(aliases, name), name)
+        # Case: aliases absent
+        aliases = []
+
+    def test_read_file(self):
+        from edit_python_pe.main import read_file
+
+        file_path = "/tmp/testfile.txt"
+        expected_content = "Hello, world!"
+        with patch("builtins.open", MagicMock()) as mock_open:
+            mock_open.return_value.__enter__.return_value.read.return_value = (
+                expected_content
+            )
+            result = read_file(file_path)
+            mock_open.assert_called_with(file_path, "r", encoding="utf-8")
+
+    def test_append_file(self):
+        from edit_python_pe.main import append_file
+
+        file_content = "Append this!"
+        file_path = "/tmp/testdir/testfile.txt"
+        with (
+            patch("os.makedirs") as makedirs,
+            patch("builtins.open", MagicMock()) as mock_open,
+        ):
+            append_file(file_content, file_path)
+            makedirs.assert_called_with("/tmp/testdir", exist_ok=True)
+            mock_open.assert_called_with(file_path, "a", encoding="utf-8")
+            handle = mock_open.return_value.__enter__.return_value
+
+    def test_compute_file_name_alias_used(self):
+        from edit_python_pe.main import compute_file_name
+
+        aliases = ["CoolAlias"]
+        name = "John Doe"
+        email = "john@example.com"
+        filename = compute_file_name(aliases, name, email)
+        self.assertTrue(filename.startswith("coolalias-"))
+        self.assertTrue(filename.endswith(".md"))
+        self.assertIn("-", filename)
+        self.assertEqual(filename.count("-"), 1)
+
+    def test_compute_file_name_name_used_if_no_alias(self):
+        from edit_python_pe.main import compute_file_name
+
+        aliases = []
+        name = "Jane Doe"
+        email = "jane@example.com"
+        filename = compute_file_name(aliases, name, email)
+        self.assertTrue(filename.startswith("jane_doe-"))
+        self.assertTrue(filename.endswith(".md"))
+
+    def test_compute_file_name_uniqueness(self):
+        from edit_python_pe.main import compute_file_name
+
+        aliases = ["Alias"]
+        name = "Name"
+        email1 = "email1@example.com"
+        email2 = "email2@example.com"
+        filename1 = compute_file_name(aliases, name, email1)
+        filename2 = compute_file_name(aliases, name, email2)
+        self.assertNotEqual(filename1, filename2)
+
+    def test_write_file(self):
+
+        from edit_python_pe.main import write_file
+
+        file_content = "Hello, world!"
+        file_path = "/tmp/testdir/testfile.txt"
+        with (
+            patch("os.makedirs") as makedirs,
+            patch("builtins.open", MagicMock()) as mock_open,
+        ):
+            write_file(file_content, file_path)
+            makedirs.assert_called_with("/tmp/testdir", exist_ok=True)
+            mock_open.assert_called_with(file_path, "w", encoding="utf-8")
+            handle = mock_open.return_value.__enter__.return_value
+            handle.write.assert_called_with(file_content)
+
+    def test_commit_and_push(self):
+        from edit_python_pe.main import commit_and_push
+
+        repo_path = "/fake/repo"
+        token = "fake-token"
+        was_changed = True
+        name_file = "test.md"
+        name = "Test Name"
+        email = "test@email.com"
+        with patch("pygit2.repository.Repository") as RepoMock:
+            repo_instance = RepoMock.return_value
+            repo_instance.index.add = MagicMock()
+            repo_instance.index.write = MagicMock()
+            repo_instance.index.write_tree = MagicMock(return_value="treeid")
+            repo_instance.head_is_unborn = False
+            repo_instance.head = MagicMock()
+            repo_instance.head.target = "commitid"
+            repo_instance.create_commit = MagicMock()
+            repo_instance.remotes = {"origin": MagicMock()}
+            repo_instance.remotes["origin"].push = MagicMock()
+            with (
+                patch("pygit2.Signature") as SignatureMock,
+                patch(
+                    "pygit2.callbacks.RemoteCallbacks"
+                ) as RemoteCallbacksMock,
+            ):
+                SignatureMock.return_value = MagicMock()
+                RemoteCallbacksMock.return_value = MagicMock()
+                commit_msg, repo, remote, callbacks = commit_and_push(
+                    repo_path,
+                    token,
+                    was_changed,
+                    name_file,
+                    name,
+                    email,
+                )
+                repo_instance.index.add_all.assert_called()
+                repo_instance.index.write.assert_called()
+                repo_instance.create_commit.assert_called()
+                repo_instance.remotes["origin"].push.assert_called()
+                self.assertEqual(commit_msg, f"Changed {name_file}")
+
+
+class TestGetRepo(unittest.TestCase):
+    @patch("edit_python_pe.main.getpass.getpass", return_value="valid-token")
+    @patch("edit_python_pe.main.Github")
+    def test_get_repo_success(self, mock_github, mock_getpass):
+        mock_repo = MagicMock()
+        mock_github.return_value.get_repo.return_value = mock_repo
+        token, repo = get_repo()
+        self.assertEqual(token, "valid-token")
+        self.assertEqual(repo, mock_repo)
+
+    @patch("edit_python_pe.main.getpass.getpass", return_value="invalid-token")
+    @patch("edit_python_pe.main.Github")
+    def test_get_repo_bad_credentials(self, mock_github, mock_getpass):
+        from github.GithubException import BadCredentialsException
+
+        mock_github.return_value.get_repo.side_effect = (
+            BadCredentialsException(401, "Bad credentials", None)
+        )
+        with self.assertRaises(SystemExit):
+            get_repo()
+
+    @patch("edit_python_pe.main.getpass.getpass", return_value="valid-token")
+    @patch("edit_python_pe.main.Github")
+    def test_get_repo_github_exception(self, mock_github, mock_getpass):
+        from github.GithubException import GithubException
+
+        mock_github.return_value.get_repo.side_effect = GithubException(
+            404, "Not found", None
+        )
+        with self.assertRaises(SystemExit):
+            get_repo()
+
+
+class TestForkRepo(unittest.TestCase):
+    @patch("edit_python_pe.main.user_data_dir", return_value="/tmp/testrepo")
+    @patch("edit_python_pe.main.os.path.exists", return_value=False)
+    @patch("edit_python_pe.main.pygit2.clone_repository")
+    @patch("edit_python_pe.main.sleep", return_value=None)
+    def test_fork_repo_clones_if_not_exists(
+        self, mock_sleep, mock_clone, mock_exists, mock_user_data_dir
+    ):
+        mock_forked_repo = MagicMock()
+        mock_forked_repo.clone_url = "https://github.com/fake/fork.git"
+        mock_original_repo = MagicMock()
+        mock_original_repo.create_fork.return_value = mock_forked_repo
+        token = "fake-token"
+        repo_path = fork_repo(token, mock_original_repo)[0]
+        mock_original_repo.create_fork.assert_called_once()
+        mock_clone.assert_called_once()
+        call_args = mock_clone.call_args
+        self.assertEqual(call_args[0][0], mock_forked_repo.clone_url)
+        self.assertEqual(call_args[0][1], repo_path)
+        self.assertEqual(repo_path, "/tmp/testrepo")
+
+    @patch("edit_python_pe.main.user_data_dir", return_value="/tmp/testrepo")
+    @patch("edit_python_pe.main.os.path.exists", return_value=True)
+    @patch("edit_python_pe.main.pygit2.clone_repository")
+    def test_fork_repo_no_clone_if_exists(
+        self, mock_clone, mock_exists, mock_user_data_dir
+    ):
+        mock_forked_repo = MagicMock()
+        mock_forked_repo.clone_url = "https://github.com/fake/fork.git"
+        mock_original_repo = MagicMock()
+        mock_original_repo.create_fork.return_value = mock_forked_repo
+        token = "fake-token"
+        repo_path = fork_repo(token, mock_original_repo)[0]
+        mock_original_repo.create_fork.assert_called_once()
+        mock_clone.assert_not_called()
+        self.assertEqual(repo_path, "/tmp/testrepo")
+
+
+class TestMainFunction(unittest.TestCase):
+    @patch("edit_python_pe.main.get_repo")
+    @patch("edit_python_pe.main.fork_repo")
+    @patch("edit_python_pe.main.MemberApp")
+    def test_main_runs_app(
+        self, mock_member_app, mock_fork_repo, mock_get_repo
+    ):
+        mock_get_repo.return_value = ("token", MagicMock())
+        mock_fork_repo.return_value = ("/tmp/testrepo", MagicMock())
+        mock_app_instance = MagicMock()
+        mock_member_app.return_value = mock_app_instance
+        main()
+        mock_get_repo.assert_called_once()
+        mock_fork_repo.assert_called_once()
+        mock_member_app.assert_called_once_with(
+            unittest.mock.ANY,
+            unittest.mock.ANY,
+            unittest.mock.ANY,
+            unittest.mock.ANY,
+        )
+        mock_app_instance.run.assert_called_once()
